@@ -24,7 +24,8 @@
  */
 
 
-#include <config.h>
+#include "config.h"
+#include <glib.h>
 #include "gnome-print-i18n.h"
 
 char *
