@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  gnome-print-master.c: A system print interface.
+ *  gnome-print-job.c: A print job interface
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -41,11 +41,11 @@
 #include "gnome-print-multipage.h"
 #include "gnome-print-job-private.h"
 
-#define noGPM_VERBOSE
+#define noJOB_VERBOSE
 
-typedef struct _GPMPrivate GPMPrivate;
+typedef struct _JOBPrivate JOBPrivate;
 
-struct _GPMPrivate {
+struct _JOBPrivate {
 	/* closed flag */
 	guint closed : 1;
 
@@ -67,16 +67,16 @@ struct _GPMPrivate {
 	GList *LY_LIST;
 };
 
-#define GNOME_PRINT_JOB_CLOSED(m) (((GPMPrivate *) (m)->priv)->closed)
+#define GNOME_PRINT_JOB_CLOSED(m) (((JOBPrivate *) (m)->priv)->closed)
 
 static void gnome_print_job_class_init (GnomePrintJobClass *klass);
-static void gnome_print_job_init (GnomePrintJob *gpm);
+static void gnome_print_job_init (GnomePrintJob *job);
 static void gnome_print_job_finalize (GObject *object);
 
-static void gpm_update_layout_data (GnomePrintJob *gpm);
-static void gpm_parse_config_data (GnomePrintJob *gpm);
-static void gpm_clear_config_data (GnomePrintJob *gpm);
-static gboolean gpm_parse_transform (guchar *str, gdouble *transform);
+static void job_update_layout_data (GnomePrintJob *job);
+static void job_parse_config_data (GnomePrintJob *job);
+static void job_clear_config_data (GnomePrintJob *job);
+static gboolean job_parse_transform (guchar *str, gdouble *transform);
 
 static GObjectClass *parent_class;
 
@@ -111,35 +111,35 @@ gnome_print_job_class_init (GnomePrintJobClass *klass)
 }
 
 static void
-gnome_print_job_init (GnomePrintJob *gpm)
+gnome_print_job_init (GnomePrintJob *job)
 {
-	gpm->config = NULL;
+	job->config = NULL;
 
-	gpm->meta = gnome_print_meta_new ();
+	job->meta = gnome_print_meta_new ();
 
-	gpm->priv = g_new0 (GPMPrivate, 1);
-	gpm_clear_config_data (gpm);
+	job->priv = g_new0 (JOBPrivate, 1);
+	job_clear_config_data (job);
 }
 
 static void
 gnome_print_job_finalize (GObject *object)
 {
-	GnomePrintJob *gpm;
+	GnomePrintJob *job;
 
-	gpm = GNOME_PRINT_JOB(object);
+	job = GNOME_PRINT_JOB(object);
 
-	if (gpm->config) {
-		gnome_print_config_unref (gpm->config);
+	if (job->config) {
+		g_object_unref (G_OBJECT (job->config));
 	}
 
-	if (gpm->meta != NULL) {
-		g_object_unref (G_OBJECT (gpm->meta));
+	if (job->meta != NULL) {
+		g_object_unref (G_OBJECT (job->meta));
 	}
 
-	if (gpm->priv) {
-		gpm_clear_config_data (gpm);
-		g_free (gpm->priv);
-		gpm->priv = NULL;
+	if (job->priv) {
+		job_clear_config_data (job);
+		g_free (job->priv);
+		job->priv = NULL;
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -147,7 +147,7 @@ gnome_print_job_finalize (GObject *object)
 
 /**
  * gnome_print_job_new:
- * @dialog: %A GnomePrintDialog
+ * @config: The options & settings for this job
  * 
  * Create a new GnomePrintJob based on the values in the
  * %GnomePrintDialog.  Range values are initialised to sensible
@@ -156,37 +156,36 @@ gnome_print_job_finalize (GObject *object)
  * 
  * Return value: A new GnomePrintJob.
  **/
-
 GnomePrintJob *
 gnome_print_job_new (GnomePrintConfig *config)
 {
-	GnomePrintJob *gpm;
+	GnomePrintJob *job;
 	
-	gpm = g_object_new (GNOME_TYPE_PRINT_JOB, NULL);
+	job = g_object_new (GNOME_TYPE_PRINT_JOB, NULL);
 
 	if (config)
-		gpm->config = gnome_print_config_ref (config);
+		job->config = gnome_print_config_ref (config);
 	else
-		gpm->config = gnome_print_config_default ();
+		job->config = gnome_print_config_default ();
 
-	return gpm;
+	return job;
 }
 
 GnomePrintConfig *
-gnome_print_job_get_config (GnomePrintJob *gpm)
+gnome_print_job_get_config (GnomePrintJob *job)
 {
-	g_return_val_if_fail (gpm != NULL, NULL);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), NULL);
+	g_return_val_if_fail (job != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), NULL);
 
-	if (gpm->config)
-		gnome_print_config_ref (gpm->config);
+	if (job->config)
+		gnome_print_config_ref (job->config);
 
-	return gpm->config;
+	return job->config;
 }
 
 /**
  * gnome_print_job_get_context:
- * @gpm: An initialised GnomePrintJob.
+ * @job: An initialised GnomePrintJob.
  * 
  * Retrieve the GnomePrintContext which applications
  * print to.
@@ -195,45 +194,45 @@ gnome_print_job_get_config (GnomePrintJob *gpm)
  **/
 
 GnomePrintContext *
-gnome_print_job_get_context (GnomePrintJob *gpm)
+gnome_print_job_get_context (GnomePrintJob *job)
 {
-	g_return_val_if_fail (gpm != NULL, NULL);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), NULL);
+	g_return_val_if_fail (job != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), NULL);
 
-	if (gpm->meta)
-		g_object_ref (G_OBJECT (gpm->meta));
+	if (job->meta)
+		g_object_ref (G_OBJECT (job->meta));
 
-	return gpm->meta;
+	return job->meta;
 }
 
 /**
  * gnome_print_job_get_pages:
- * @gpm: An initialised and closed GnomePrintJob.
+ * @job: An initialised and closed GnomePrintJob.
  * 
  * Find the number of pages stored in a completed printout.
  * 
- * Return value: If @gpm has not been closed using
+ * Return value: If @job has not been closed using
  * gnome_print_job_close(), then 0, otherwise the number
  * of pages created by the application.
  **/
 
 int
-gnome_print_job_get_pages (GnomePrintJob *gpm)
+gnome_print_job_get_pages (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	gint mp;
 
-	g_return_val_if_fail (gpm != NULL, 0);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), 0);
+	g_return_val_if_fail (job != NULL, 0);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), 0);
 
-	if (!GNOME_PRINT_JOB_CLOSED (gpm))
+	if (!GNOME_PRINT_JOB_CLOSED (job))
 		return 0;
 
-	gpm_update_layout_data (gpm);
+	job_update_layout_data (job);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	mp = gnome_print_meta_get_pages (GNOME_PRINT_META (gpm->meta));
+	mp = gnome_print_meta_get_pages (GNOME_PRINT_META (job->meta));
 
 	if (pp->num_affines <= 1)
 		return mp;
@@ -249,16 +248,16 @@ gnome_print_job_get_pages (GnomePrintJob *gpm)
 gboolean
 gnome_print_job_get_page_size_from_config (GnomePrintConfig *config, gdouble *width, gdouble *height)
 {
-	GnomePrintJob *gpm;
-	GPMPrivate *pp;
+	GnomePrintJob *job;
+	JOBPrivate *pp;
 
 	g_return_val_if_fail (config != NULL, FALSE);
 
-	gpm = gnome_print_job_new (config);
+	job = gnome_print_job_new (config);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	gpm_update_layout_data (gpm);
+	job_update_layout_data (job);
 
 	if (pp->LY_LIST) {
 		/* Success */
@@ -278,25 +277,25 @@ gnome_print_job_get_page_size_from_config (GnomePrintConfig *config, gdouble *wi
 
 /**
  * gnome_print_job_close:
- * @gpm: A GnomePrintJob which has had printing performed
+ * @job: A GnomePrintJob which has had printing performed
  * 
- *  * Closes the GnomePrintJob @gpm, ready for printing or previewing.
+ *  * Closes the GnomePrintJob @job, ready for printing or previewing.
  * 
  * Return Value: 
  **/
 gint
-gnome_print_job_close (GnomePrintJob *gpm)
+gnome_print_job_close (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 
-	g_return_val_if_fail (gpm != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), GNOME_PRINT_ERROR_UNKNOWN);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
 	if (!pp->closed) {
 		pp->closed = TRUE;
-		return gnome_print_context_close (gpm->meta);
+		return gnome_print_context_close (job->meta);
 	}
 
 	return GNOME_PRINT_ERROR_UNKNOWN;
@@ -304,7 +303,7 @@ gnome_print_job_close (GnomePrintJob *gpm)
 
 /**
  * gnome_print_job_print:
- * @gpm: A completed GnomePrintJob.
+ * @job: A completed GnomePrintJob.
  * 
  * Print the pages stored in the GnomePrintJob to
  * the phyisical printing device.
@@ -316,9 +315,9 @@ gnome_print_job_close (GnomePrintJob *gpm)
  **/
 
 gint
-gnome_print_job_print (GnomePrintJob *gpm)
+gnome_print_job_print (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	GnomePrintContext *ctx;
 	gint lpages, copies, nstacks, npages, nsheets;
 	gboolean collate, is_multipage;
@@ -327,24 +326,24 @@ gnome_print_job_print (GnomePrintJob *gpm)
 	gint blen;
 	gint ret;
 
-	g_return_val_if_fail (gpm != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (gpm->priv, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job->priv, GNOME_PRINT_ERROR_UNKNOWN);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	ctx = gnome_print_context_new (gpm->config);
+	ctx = gnome_print_context_new (job->config);
 	g_return_val_if_fail (ctx != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
 	/* Get number of pages in metafile */
-	lpages = gnome_print_meta_get_pages (GNOME_PRINT_META (gpm->meta));
+	lpages = gnome_print_meta_get_pages (GNOME_PRINT_META (job->meta));
 	if (lpages < 1)
 		return GNOME_PRINT_OK;
 	npages = lpages;
 
 	/* Update layout data */
 	is_multipage = FALSE;
-	gpm_update_layout_data (gpm);
+	job_update_layout_data (job);
 	if (pp->LY_LIST) {
 		GnomePrintContext *mp;
 		/* Find out physical page count */
@@ -357,9 +356,9 @@ gnome_print_job_print (GnomePrintJob *gpm)
 	}
 
 	collate = FALSE;
-	gnome_print_config_get_boolean (gpm->config, GNOME_PRINT_KEY_COLLATE, &collate);
+	gnome_print_config_get_boolean (job->config, GNOME_PRINT_KEY_COLLATE, &collate);
 	copies = 1;
-	gnome_print_config_get_int (gpm->config, GNOME_PRINT_KEY_NUM_COPIES, &copies);
+	gnome_print_config_get_int (job->config, GNOME_PRINT_KEY_NUM_COPIES, &copies);
 
 	if (collate) {
 		nstacks = copies;
@@ -369,8 +368,8 @@ gnome_print_job_print (GnomePrintJob *gpm)
 		nsheets = copies;
 	}
 	
-	buf = gnome_print_meta_get_buffer (GNOME_PRINT_META (gpm->meta));
-	blen = gnome_print_meta_get_length (GNOME_PRINT_META (gpm->meta));
+	buf = gnome_print_meta_get_buffer (GNOME_PRINT_META (job->meta));
+	blen = gnome_print_meta_get_length (GNOME_PRINT_META (job->meta));
 
 	for (stack = 0; stack < nstacks; stack++) {
 		gint page;
@@ -400,27 +399,27 @@ gnome_print_job_print (GnomePrintJob *gpm)
 
 /* Renders printout to specified context */
 gint
-gnome_print_job_render (GnomePrintJob *gpm, GnomePrintContext *ctx)
+gnome_print_job_render (GnomePrintJob *job, GnomePrintContext *ctx)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	const guchar *data;
 	gint len;
 	gint ret;
 
-	g_return_val_if_fail (gpm != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (ctx != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (ctx), GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (gpm->priv, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job->priv, GNOME_PRINT_ERROR_UNKNOWN);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	data = gnome_print_meta_get_buffer (GNOME_PRINT_META (gpm->meta));
+	data = gnome_print_meta_get_buffer (GNOME_PRINT_META (job->meta));
 	g_return_val_if_fail (data != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	len = gnome_print_meta_get_length (GNOME_PRINT_META (gpm->meta));
+	len = gnome_print_meta_get_length (GNOME_PRINT_META (job->meta));
 	g_return_val_if_fail (len > 0, GNOME_PRINT_ERROR_UNKNOWN);
 
-	gpm_update_layout_data (gpm);
+	job_update_layout_data (job);
 	if (pp->LY_LIST) {
 		GnomePrintContext *mp;
 		mp = gnome_print_multipage_new (ctx, pp->LY_LIST);
@@ -436,28 +435,28 @@ gnome_print_job_render (GnomePrintJob *gpm, GnomePrintContext *ctx)
 
 /* Renders specified page */
 gint
-gnome_print_job_render_page (GnomePrintJob *gpm, GnomePrintContext *ctx, gint page, gboolean pageops)
+gnome_print_job_render_page (GnomePrintJob *job, GnomePrintContext *ctx, gint page, gboolean pageops)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	const guchar *data;
 	gint len, pages;
 	gint ret;
 
-	g_return_val_if_fail (gpm != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (GNOME_IS_PRINT_JOB (gpm), GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (GNOME_IS_PRINT_JOB (job), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (ctx != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (ctx), GNOME_PRINT_ERROR_UNKNOWN);
-	g_return_val_if_fail (gpm->priv, GNOME_PRINT_ERROR_UNKNOWN);
+	g_return_val_if_fail (job->priv, GNOME_PRINT_ERROR_UNKNOWN);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	data = gnome_print_meta_get_buffer (GNOME_PRINT_META (gpm->meta));
+	data = gnome_print_meta_get_buffer (GNOME_PRINT_META (job->meta));
 	g_return_val_if_fail (data != NULL, GNOME_PRINT_ERROR_UNKNOWN);
-	len = gnome_print_meta_get_length (GNOME_PRINT_META (gpm->meta));
+	len = gnome_print_meta_get_length (GNOME_PRINT_META (job->meta));
 	g_return_val_if_fail (len > 0, GNOME_PRINT_ERROR_UNKNOWN);
-	pages = gnome_print_meta_get_pages (GNOME_PRINT_META (gpm->meta));
+	pages = gnome_print_meta_get_pages (GNOME_PRINT_META (job->meta));
 
-	gpm_update_layout_data (gpm);
+	job_update_layout_data (job);
 	if (pp->LY_LIST) {
 		GnomePrintContext *meta, *mp;
 		gint start, p;
@@ -510,7 +509,7 @@ gnome_print_job_render_page (GnomePrintJob *gpm, GnomePrintContext *ctx, gint pa
  */
 
 #define EPSILON 1e-9
-#ifdef GPM_VERBOSE
+#ifdef JOB_VERBOSE
 #define PRINT_2(s,a,b) g_print ("%s %g %g\n", s, (a), (b))
 #define PRINT_DRECT(s,a) g_print ("%s %g %g %g %g\n", (s), (a)->x0, (a)->y0, (a)->x1, (a)->y1)
 #define PRINT_AFFINE(s,a) g_print ("%s %g %g %g %g %g %g\n", (s), *(a), *((a) + 1), *((a) + 2), *((a) + 3), *((a) + 4), *((a) + 5))
@@ -521,19 +520,19 @@ gnome_print_job_render_page (GnomePrintJob *gpm, GnomePrintContext *ctx, gint pa
 #endif
 
 static void
-gpm_update_layout_data (GnomePrintJob *gpm)
+job_update_layout_data (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	ArtDRect area, r;
 	gdouble t;
 	gdouble a[6];
 	gint i;
 
-	g_return_if_fail (gpm->priv);
+	g_return_if_fail (job->priv);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	gpm_parse_config_data (gpm);
+	job_parse_config_data (job);
 
 	/* Now comes the fun part */
 
@@ -627,20 +626,20 @@ gpm_update_layout_data (GnomePrintJob *gpm)
 }
 
 static void
-gpm_parse_config_data (GnomePrintJob *gpm)
+job_parse_config_data (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 	const GnomePrintUnit *unit;
 	GPANode *layout;
 	gchar *loc;
 
-	g_return_if_fail (gpm->priv);
+	g_return_if_fail (job->priv);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
-	gpm_clear_config_data (gpm);
+	job_clear_config_data (job);
 
-	g_return_if_fail (gpm->config);
+	g_return_if_fail (job->config);
 
 	/* Now the fun part */
 
@@ -648,22 +647,22 @@ gpm_parse_config_data (GnomePrintJob *gpm)
 	setlocale (LC_NUMERIC, "C");
 
 	/* Physical size */
-	if (gnome_print_config_get_length (gpm->config, GNOME_PRINT_KEY_PAPER_WIDTH, &pp->pw, &unit)) {
+	if (gnome_print_config_get_length (job->config, GNOME_PRINT_KEY_PAPER_WIDTH, &pp->pw, &unit)) {
 		gnome_print_convert_distance (&pp->pw, unit, GNOME_PRINT_PS_UNIT);
 	}
-	if (gnome_print_config_get_length (gpm->config, GNOME_PRINT_KEY_PAPER_HEIGHT, &pp->ph, &unit)) {
+	if (gnome_print_config_get_length (job->config, GNOME_PRINT_KEY_PAPER_HEIGHT, &pp->ph, &unit)) {
 		gnome_print_convert_distance (&pp->ph, unit, GNOME_PRINT_PS_UNIT);
 	}
 	/* Physical orientation */
-	gnome_print_config_get_transform (gpm->config, GNOME_PRINT_KEY_PAPER_ORIENTATION_MATRIX, pp->porient);
+	gnome_print_config_get_transform (job->config, GNOME_PRINT_KEY_PAPER_ORIENTATION_MATRIX, pp->porient);
 	/* Logical orientation */
-	gnome_print_config_get_transform (gpm->config, GNOME_PRINT_KEY_PAGE_ORIENTATION_MATRIX, pp->lorient);
+	gnome_print_config_get_transform (job->config, GNOME_PRINT_KEY_PAGE_ORIENTATION_MATRIX, pp->lorient);
 	/* Layout size */
-	gnome_print_config_get_double (gpm->config, GNOME_PRINT_KEY_LAYOUT_WIDTH, &pp->lyw);
-	gnome_print_config_get_double (gpm->config, GNOME_PRINT_KEY_LAYOUT_HEIGHT, &pp->lyh);
+	gnome_print_config_get_double (job->config, GNOME_PRINT_KEY_LAYOUT_WIDTH, &pp->lyw);
+	gnome_print_config_get_double (job->config, GNOME_PRINT_KEY_LAYOUT_HEIGHT, &pp->lyh);
 
 	/* Now come the affines */
-	layout = gpa_node_get_child_from_path (GNOME_PRINT_CONFIG_NODE (gpm->config), GNOME_PRINT_KEY_LAYOUT);
+	layout = gpa_node_get_child_from_path (GNOME_PRINT_CONFIG_NODE (job->config), GNOME_PRINT_KEY_LAYOUT);
 	if (layout) {
 		gint numlp;
 		numlp = 0;
@@ -682,7 +681,7 @@ gpm_parse_config_data (GnomePrintJob *gpm)
 					gpa_node_unref (page);
 					if (!transform)
 						break;
-					gpm_parse_transform (transform, affines + 6 * pagenum);
+					job_parse_transform (transform, affines + 6 * pagenum);
 					g_free (transform);
 					pagenum += 1;
 					if (pagenum >= numlp)
@@ -712,13 +711,13 @@ gpm_parse_config_data (GnomePrintJob *gpm)
 #define A4_HEIGHT (297 * 72 / 25.4)
 
 static void
-gpm_clear_config_data (GnomePrintJob *gpm)
+job_clear_config_data (GnomePrintJob *job)
 {
-	GPMPrivate *pp;
+	JOBPrivate *pp;
 
-	g_return_if_fail (gpm->priv);
+	g_return_if_fail (job->priv);
 
-	pp = gpm->priv;
+	pp = job->priv;
 
 	pp->pw = A4_WIDTH;
 	pp->ph = A4_HEIGHT;
@@ -839,7 +838,7 @@ gnome_print_config_get_layout_data (GnomePrintConfig *config,
 				gpa_node_unref (page);
 				if (!transform)
 					break;
-				gpm_parse_transform (transform, pages[pagenum].matrix);
+				job_parse_transform (transform, pages[pagenum].matrix);
 				g_free (transform);
 				pagenum += 1;
 				if (pagenum >= numlp)
@@ -1005,7 +1004,7 @@ gnome_print_layout_free (GnomePrintLayout *layout)
 }
 
 static gboolean
-gpm_parse_transform (guchar *str, gdouble *transform)
+job_parse_transform (guchar *str, gdouble *transform)
 {
 	gdouble t[6];
 	guchar *p;
@@ -1059,17 +1058,17 @@ gpm_parse_transform (guchar *str, gdouble *transform)
  * Return Value: 
  **/
 gint
-gnome_print_job_print_to_file (GnomePrintJob *gpm, gchar *output)
+gnome_print_job_print_to_file (GnomePrintJob *job, gchar *output)
 {
 	if (output) {
-		gnome_print_config_set (gpm->config, "Settings.Transport.Backend",    "file");
-		gnome_print_config_set (gpm->config, GNOME_PRINT_KEY_OUTPUT_FILENAME, output);
+		gnome_print_config_set (job->config, "Settings.Transport.Backend",    "file");
+		gnome_print_config_set (job->config, GNOME_PRINT_KEY_OUTPUT_FILENAME, output);
 	} else {
 		g_print ("Setting print to file to off, using LPR\n");
 		/* In the future we might want to use the default or even better,
 		 * go back to the prev. selected printer
 		 */
-		gnome_print_config_set (gpm->config, "Settings.Transport.Backend", "lpr");
+		gnome_print_config_set (job->config, "Settings.Transport.Backend", "lpr");
 	}
 	
 	return GNOME_PRINT_OK;
@@ -1097,7 +1096,7 @@ gnome_print_config_get_transform (GnomePrintConfig *config, const guchar *key, g
 	loc = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 
-	ret = gpm_parse_transform (v, t);
+	ret = job_parse_transform (v, t);
 	g_free (v);
 	if (ret) {
 		memcpy (transform, t, 6 * sizeof (gdouble));
