@@ -48,7 +48,6 @@
 
 static void gnome_print_context_class_init (GnomePrintContextClass *klass);
 static void gnome_print_context_init (GnomePrintContext *pc);
-
 static void gnome_print_context_finalize (GObject *object);
 
 #ifdef GNOME_PRINT_ENABLE_MODULE_DRIVERS
@@ -124,6 +123,8 @@ gnome_print_context_finalize (GObject *object)
 gint
 gnome_print_context_construct (GnomePrintContext *pc, GnomePrintConfig *config)
 {
+	GnomePrintReturnCode retval = GNOME_PRINT_ERROR_UNKNOWN;
+	
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_UNKNOWN);
 	g_return_val_if_fail (config != NULL, GNOME_PRINT_ERROR_UNKNOWN);
@@ -133,9 +134,9 @@ gnome_print_context_construct (GnomePrintContext *pc, GnomePrintConfig *config)
 	pc->config = gnome_print_config_ref (config);
 
 	if (GNOME_PRINT_CONTEXT_GET_CLASS (pc)->construct)
-		GNOME_PRINT_CONTEXT_GET_CLASS (pc)->construct (pc);
+		retval = GNOME_PRINT_CONTEXT_GET_CLASS (pc)->construct (pc);
 
-	return GNOME_PRINT_OK;
+	return retval;
 }
 
 gint
@@ -546,7 +547,11 @@ gnome_print_context_new (GnomePrintConfig *config)
 		GnomePrintContext *ps;
 		g_print ("Printing to Postscript...\n");
 		ps = gnome_print_ps2_new (config);
+		if (ps == NULL)
+			return NULL;
 		pc = gnome_print_frgba_new (ps);
+		if (pc == NULL)
+			return NULL;
 		g_object_unref (G_OBJECT (ps));
 		g_free (drivername);
 		return pc;
@@ -555,6 +560,8 @@ gnome_print_context_new (GnomePrintConfig *config)
 	if (strcmp (drivername, "gnome-print-pdf") == 0) {
 		g_print ("Printing to PDF ...\n");
 		pc = gnome_print_pdf_new (config);
+		if (pc == NULL)
+			return NULL;
 		g_free (drivername);
 		return pc;
 	}
