@@ -575,7 +575,6 @@ gpa_printer_list_load (void)
 {
 	GPARoot *root = GPA_ROOT (gpa_root_get ());
 	GPAList *printers;
-	gchar *home_dir;
 
 	g_return_val_if_fail (root != NULL,        NULL);
 	g_return_val_if_fail (root->media != NULL, NULL);
@@ -587,14 +586,9 @@ gpa_printer_list_load (void)
 	printers = gpa_list_new (GPA_TYPE_PRINTER, "Printers", TRUE);
 	g_object_weak_ref (G_OBJECT (printers), gpa_printers_gone, &printers);
 
-	home_dir = g_strdup_printf ("%s/%s", g_get_home_dir (), ".gnome/printers");
-	
-	gpa_printer_list_load_from_dir (printers, home_dir);
-	gpa_printer_list_load_from_dir (printers, DATADIR "/gnome-print-2.0/printers");
+	gpa_printer_list_load_from_dir (printers, GNOME_PRINT_DATA_DIR "/printers");
 	gpa_printer_list_load_from_module_dir (printers, GPA_MODULES_DIR);
 
-	g_free (home_dir);
-
 	/* We should always have printers, at least one loaded from code. (Chema) */
 	g_assert (printers->children);
 
